Module block_array
ibdgen
0.1.2
Module block_
array
Module Items
Structs
In crate ibdgen
ibdgen
Module
block_
array
Structs

Block
Array
Represents a block array, which is a matrix where each row represents a block and each column represents a treatment.